==> kubernetes-model-apiextensions-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/ConversionReviewFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConversionReviewFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent<A>{
  public ConversionReviewFluentImpl() {
  }
  public ConversionReviewFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReview instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withRequest(instance.getRequest()); 
    this.withResponse(instance.getResponse()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder request;
  private io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder response;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildRequest instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest getRequest() {
    return this.request!=null?this.request.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest buildRequest() {
    return this.request!=null?this.request.build():null;
  }
  public A withRequest(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest request) {
    _visitables.get("request").remove(this.request);
    if (request!=null){ this.request= new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder(request); _visitables.get("request").add(this.request);} return (A) this;
  }
  public java.lang.Boolean hasRequest() {
    return this.request != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> withNewRequest() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluentImpl.RequestNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> withNewRequestLike(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluentImpl.RequestNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> editRequest() {
    return withNewRequestLike(getRequest());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> editOrNewRequest() {
    return withNewRequestLike(getRequest() != null ? getRequest(): new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> editOrNewRequestLike(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest item) {
    return withNewRequestLike(getRequest() != null ? getRequest(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildResponse instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse getResponse() {
    return this.response!=null?this.response.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse buildResponse() {
    return this.response!=null?this.response.build():null;
  }
  public A withResponse(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse response) {
    _visitables.get("response").remove(this.response);
    if (response!=null){ this.response= new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder(response); _visitables.get("response").add(this.response);} return (A) this;
  }
  public java.lang.Boolean hasResponse() {
    return this.response != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> withNewResponse() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluentImpl.ResponseNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> withNewResponseLike(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluentImpl.ResponseNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> editResponse() {
    return withNewResponseLike(getResponse());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> editOrNewResponse() {
    return withNewResponseLike(getResponse() != null ? getResponse(): new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> editOrNewResponseLike(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse item) {
    return withNewResponseLike(getResponse() != null ? getResponse(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConversionReviewFluentImpl that = (ConversionReviewFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (request != null ? !request.equals(that.request) :that.request != null) return false;
    if (response != null ? !response.equals(that.response) :that.response != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  request,  response,  additionalProperties,  super.hashCode());
  }
  public class RequestNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    RequestNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder(this, item);
    }
    RequestNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder builder;
    public N and() {
      return (N) ConversionReviewFluentImpl.this.withRequest(builder.build());
    }
    public N endRequest() {
      return and();
    }
    
  }
  public class ResponseNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ResponseNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder(this, item);
    }
    ResponseNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder builder;
    public N and() {
      return (N) ConversionReviewFluentImpl.this.withResponse(builder.build());
    }
    public N endResponse() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apiextensions-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/ConversionReviewFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ConversionReviewFluentImpl<A extends io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent<A>{
  public ConversionReviewFluentImpl() {
  }
  public ConversionReviewFluentImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReview instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withRequest(instance.getRequest()); 
    this.withResponse(instance.getResponse()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String apiVersion;
  private java.lang.String kind;
  private io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder request;
  private io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder response;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(java.lang.String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public java.lang.Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0) {
    return (A)withApiVersion(new String(arg0));
  }
  public java.lang.String getKind() {
    return this.kind;
  }
  public A withKind(java.lang.String kind) {
    this.kind=kind; return (A) this;
  }
  public java.lang.Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0) {
    return (A)withKind(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildRequest instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest getRequest() {
    return this.request!=null?this.request.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest buildRequest() {
    return this.request!=null?this.request.build():null;
  }
  public A withRequest(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest request) {
    _visitables.get("request").remove(this.request);
    if (request!=null){ this.request= new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder(request); _visitables.get("request").add(this.request);} return (A) this;
  }
  public java.lang.Boolean hasRequest() {
    return this.request != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> withNewRequest() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluentImpl.RequestNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> withNewRequestLike(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluentImpl.RequestNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> editRequest() {
    return withNewRequestLike(getRequest());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> editOrNewRequest() {
    return withNewRequestLike(getRequest() != null ? getRequest(): new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<A> editOrNewRequestLike(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest item) {
    return withNewRequestLike(getRequest() != null ? getRequest(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildResponse instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse getResponse() {
    return this.response!=null?this.response.build():null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse buildResponse() {
    return this.response!=null?this.response.build():null;
  }
  public A withResponse(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse response) {
    _visitables.get("response").remove(this.response);
    if (response!=null){ this.response= new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder(response); _visitables.get("response").add(this.response);} return (A) this;
  }
  public java.lang.Boolean hasResponse() {
    return this.response != null;
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> withNewResponse() {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluentImpl.ResponseNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> withNewResponseLike(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse item) {
    return new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluentImpl.ResponseNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> editResponse() {
    return withNewResponseLike(getResponse());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> editOrNewResponse() {
    return withNewResponseLike(getResponse() != null ? getResponse(): new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<A> editOrNewResponseLike(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse item) {
    return withNewResponseLike(getResponse() != null ? getResponse(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConversionReviewFluentImpl that = (ConversionReviewFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (request != null ? !request.equals(that.request) :that.request != null) return false;
    if (response != null ? !response.equals(that.response) :that.response != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  request,  response,  additionalProperties,  super.hashCode());
  }
  public class RequestNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.RequestNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    RequestNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequest item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder(this, item);
    }
    RequestNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionRequestBuilder builder;
    public N and() {
      return (N) ConversionReviewFluentImpl.this.withRequest(builder.build());
    }
    public N endRequest() {
      return and();
    }
    
  }
  public class ResponseNestedImpl<N> extends io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseFluentImpl<io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<N>> implements io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionReviewFluent.ResponseNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ResponseNestedImpl(io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponse item) {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder(this, item);
    }
    ResponseNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder(this);
    }
    io.fabric8.kubernetes.api.model.apiextensions.v1.ConversionResponseBuilder builder;
    public N and() {
      return (N) ConversionReviewFluentImpl.this.withResponse(builder.build());
    }
    public N endResponse() {
      return and();
    }
    
  }
  
}
